#include "ServiceDiscoveryIfce.h"
#include "Common.h"
#include <stdio.h>

LDAP *ld = NULL;
char *errbuf = NULL;
int errbufsz = 1024;

static int counter = 0;

void global_get_connection(void) __attribute__((constructor));
void global_close_connection(void)  __attribute__((destructor));

void global_close_connection(void){
 
	close_connection(ld);
	if(errbuf)
		free(errbuf);
}


void global_get_connection(void){
 /*
 * It seems that Glib uses some kind of internal memory allocation mechanism which means that it 
 * doesn't necessarily frees up allocated memory after calling the deallocation functions
 * The solution is to add the following single line of code BEFORE any Glib calls that can allocate 
 * memory. This ensures that Glib always allocates just as much memory as needed and completely frees 
 * it up thereafter. The documentation says that this is a debug-only setting, 
 * so it won't suffer performance penalty in release builds.
 */
 g_setenv("G_SLICE","always-malloc",1); 
 SDException exception;
 errbuf = (char *) malloc(1024);
 ld = get_connection(&exception, errbuf, errbufsz);
 /*this is called before main, so in case of an error print in stderr */
 if(!ld)
 {
	fprintf(stderr, "%s\n", errbuf);
 }	
}


